@@ -1,10 +1,11 @@
+from ctypes import POINTER, byref, c_bool, c_uint, c_uint16, c_void_p
 from enum import IntEnum, auto
 from typing import Final, List, NewType, Tuple
-from ctypes import POINTER, byref
-from ctypes import c_void_p, c_uint, c_bool, c_uint16
 
+from koda import Err, Ok, Result
+
+from . import Ft4222Exception, Ft4222Status, FtHandle, GpioTrigger
 from .dll_loader import ftlib
-from . import Err, FtHandle, Ok, Result, Ft4222Exception, Ft4222Status, GpioTrigger
 
 GpioHandle = NewType("GpioHandle", FtHandle)
 
