@@ -1,11 +1,11 @@
-from ctypes import POINTER, byref, c_char_p
-from ctypes import c_void_p, c_uint32, c_uint8, c_uint16
-
+from ctypes import POINTER, byref, c_char_p, c_uint8, c_uint16, c_uint32, c_void_p
 from enum import IntFlag
 from typing import NewType
 
+from koda import Err, Ok, Result
+
+from .. import Ft4222Exception, Ft4222Status, FtHandle
 from ..dll_loader import ftlib
-from .. import FtHandle, Result, Ok, Err, Ft4222Status, Ft4222Exception
 
 I2cMasterHandle = NewType("I2cMasterHandle", FtHandle)
 
